@@ -5,8 +5,8 @@ test_that("printTable", {
   # create dataframe
   dat <- createDF(nVP = 6, nTrl = 1,
                   design = list("Comp" = c("comp", "incomp")))
-  dat <- addDataDF(dat, RT = list("Comp_comp"   = c(500, 150, 100),
-                                  "Comp_incomp" = c(520, 150, 100)))
+  dat <- addDataDF(dat, RT = list("Comp comp"   = c(500, 150, 100),
+                                  "Comp incomp" = c(520, 150, 100)))
 
   # base R aov
   aovRT <- aov(RT ~ Comp + Error(VP/Comp), dat)
@@ -19,6 +19,7 @@ test_that("printTable", {
 
   testthat::expect_error(printTable(dat), NA)
   testthat::expect_error(printTable(dat, caption = "Test", digits = c(0, 2)), NA)
+  testthat::expect_error(printTable(dat, caption = "Test", digits = c(0, 2)), NA)
   testthat::expect_error(printTable(dat, caption = "Test", digits = c(0, 2, 0)))
   testthat::expect_error(printTable(aovRT$ANOVA), NA)
 
